// -----------------------------------------------------------------------------
//
// Copyright 2013(c) Analog Devices, Inc.
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
//  - Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
//  - Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in
//    the documentation and/or other materials provided with the
//    distribution.
//  - Neither the name of Analog Devices, Inc. nor the names of its
//    contributors may be used to endorse or promote products derived
//    from this software without specific prior written permission.
//  - The use of this software may or may not infringe the patent rights
//    of one or more patent holders.  This license does not release you
//    from the requirement that you obtain separate licenses from these
//    patent holders to use this software.
//  - Use of the software either in source or binary form, must be run
//    on or directly connected to an Analog Devices Inc. component.
//
// THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
// AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// -----------------------------------------------------------------------------
// FILE NAME :      ced1z.v
// MODULE NAME :    ced1z
// AUTHOR :         Istvan Csomortani
// AUTHOR'S EMAIL : istvan.csomortani@analog.com
// -----------------------------------------------------------------------------
// SVN REVISION: 1984
// -----------------------------------------------------------------------------
// KEYWORDS : AD7262, Nios II
// -----------------------------------------------------------------------------
// PURPOSE : Top level of the Nios II based system
// -----------------------------------------------------------------------------
// REUSE ISSUES
// Reset Strategy      : Active low reset signal
// Clock Domains       : 2 clock - the system clock 48Mhz
//                               - the SPI clock ~35 MHz
// Critical Timing     :
// Test Features       :
// Asynchronous I/F    :
// Instantiations      : uC
// Synthesizable (y/n) : Y
// Target Device       : EP1C4F400C6
// Other               :
// -----------------------------------------------------------------------------

`timescale 1 ns / 100 ps

module ced1z_eval(
    input   USB_CLOCKOUT,   //Clock
    input   RESET_N,        //Reset
//SRAM
    inout   SRAM_D0,
    inout   SRAM_D1,
    inout   SRAM_D2,
    inout   SRAM_D3,
    inout   SRAM_D4,
    inout   SRAM_D5,
    inout   SRAM_D6,
    inout   SRAM_D7,
    inout   SRAM_D8,
    inout   SRAM_D9,
    inout   SRAM_D10,
    inout   SRAM_D11,
    inout   SRAM_D12,
    inout   SRAM_D13,
    inout   SRAM_D14,
    inout   SRAM_D15,
    output  SRAM_A0,
    output  SRAM_A1,
    output  SRAM_A2,
    output  SRAM_A3,
    output  SRAM_A4,
    output  SRAM_A5,
    output  SRAM_A6,
    output  SRAM_A7,
    output  SRAM_A8,
    output  SRAM_A9,
    output  SRAM_A10,
    output  SRAM_A11,
    output  SRAM_A12,
    output  SRAM_A13,
    output  SRAM_A14,
    output  SRAM_A15,
    output  SRAM_A16,
    output  SRAM_A17,
    output  SRAM_A18,
    output  SRAM_A19,
    output  SRAM_A20,
    output  SRAM_WE_N,
    output  SRAM_OE_N,
    output  SRAM_CE1_N,
//LEDS
    output  LED_D15,
    output  LED_IO,
    output  LED_TRANSFER,

//ADC signals
    output  SCLK,
    output  CS_N,
    output  PD0_DIN,
    input   DOUTA,
    input   DOUTB,
    output  G0,
    output  G1,
    output  G2,
    output  G3,
    output  PD1,
    output  PD2,
    output  CAL,

// Activation of the output power
    output  PWR_EN_REG_CLK,
    output  PWR_I2C_A1,
    output  PWR_I2C_A0,
    output  PWR_I2C_WR_N,
    output  PWR_I2C_RD_N,
    output  PWR_I2C_CS_N,

    inout  PWR_D7,
    inout  PWR_D6,
    inout  PWR_D5,
    inout  PWR_D4,
    inout  PWR_D3,
    inout  PWR_D2,
    inout  PWR_D1,
    inout  PWR_D0
);

    uC u0 (
        .led_o_export                                      ({LED_IO,LED_D15,LED_TRANSFER}),                 // led_o.export
        .tristate_conduit_bridge_sram_tcm_address_out      ({SRAM_A20,SRAM_A19,SRAM_A18,SRAM_A17,SRAM_A16,SRAM_A15,SRAM_A14,SRAM_A13,SRAM_A12,SRAM_A11,SRAM_A10,SRAM_A9,SRAM_A8,SRAM_A7,SRAM_A6,SRAM_A5,SRAM_A4,SRAM_A3,SRAM_A2,SRAM_A1,SRAM_A0}),      // tristate_conduit_bridge.sram_tcm_address_out
        .tristate_conduit_bridge_sram_tcm_data_out         ({SRAM_D15,SRAM_D14,SRAM_D13,SRAM_D12,SRAM_D11,SRAM_D10,SRAM_D9,SRAM_D8,SRAM_D7,SRAM_D6,SRAM_D5,SRAM_D4,SRAM_D3,SRAM_D2,SRAM_D1,SRAM_D0}),         //                        .sram_tcm_data_out
        .tristate_conduit_bridge_sram_tcm_chipselect_n_out (SRAM_CE1_N),                                    // .sram_tcm_chipselect_n_out
        .tristate_conduit_bridge_sram_tcm_write_n_out      (SRAM_WE_N),                                     // .sram_tcm_write_n_out
        .tristate_conduit_bridge_sram_tcm_read_n_out       (SRAM_OE_N),                                     // .sram_tcm_read_n_out
        .mainpll_areset_export                             (~RESET_N),                                      // mainpll_areset.export
        .mainpll_locked_export                             (),                                              // mainpll_locked.export
        .mainpll_phasedone_export                          (),                                              // mainpll_phasedone.export
        .clk_in_clk                                        (USB_CLOCKOUT),                                  // clk_in.clk
        .reset_in_reset_n                                  (RESET_N),                                       // reset_in.reset_n
        .pwr_data_o_export                                 ({PWR_D7,PWR_D6,PWR_D5,PWR_D4,PWR_D3,PWR_D2,PWR_D1,PWR_D0}),          // pwr_data_o.export
        .i2c_int_o_export                                  ({PWR_I2C_A1, PWR_I2C_A0, PWR_I2C_CS_N, PWR_I2C_RD_N, PWR_I2C_WR_N}), // i2c_int_o.export
        .pwr_en_clk_o_export                               (PWR_EN_REG_CLK),                                // pwr_en_clk_o.export
        .ad7262_0_cs_n_o                                   (CS_N),                                          // .cs_n_o
        .ad7262_0_doutb_i                                  (DOUTB),                                         // .doutb_i
        .ad7262_0_sclk_o                                   (SCLK),                                          // .sclk_o
        .ad7262_0_douta_i                                  (DOUTA),                                         // .douta_i
        .gain_select_export                                ({G3, G2, G1, G0}),
        .pwr_modes_export                                  ({PD2, PD1, PD0_DIN}),
        .cal_export                                        (CAL)
    );

endmodule
