/**************************************************************************//**
*   @file   ad7262.h
*   @brief  Header file for the ad7262 ADC altera avalon IP
*   @author Istvan Csomortani
*   @author's mail istvan.csomortani@analog.com
*
*******************************************************************************
* Copyright 2013(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1984
******************************************************************************/
#ifndef __ad7262_H__
#define __ad7262_H__

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/

#include "alt_types.h"

/*****************************************************************************/
/******************* Macros and Constants Definitions ************************/
/*****************************************************************************/

#define MEMORY_LINE_SIZE    512
#define MAX_MEMORY_LINES    1024
#define MEMORY_SIZE         (MEMORY_LINE_SIZE * MAX_MEMORY_LINES)

// ADC Register Address
#define ADC_RESULT          0
#define ADC_CONTROL         1
#define ADC_A_OFFSET        2
#define ADC_B_OFFSET        3
#define ADC_A_GAIN          4
#define ADC_B_GAIN          5

// ADC Control Register 1 bits offset
#define ADC_CNT_G0          0
#define ADC_CNT_G1          1
#define ADC_CNT_G2          2
#define ADC_CNT_G3          3
#define ADC_CNT_PD0         4
#define ADC_CNT_PD1         5
#define ADC_CNT_PD2         6
#define ADC_CNT_CAL         7
#define ADC_CNT_RD          8

// HDL core's control register bits
#define START_ACQ           0
#define SW_RESET            1
#define CNTR_FIX_LOC        2
#define WR_DATA             3
#define TEST_MODE           4
#define PIN_CNTRL           5

/*****************************************************************************/
/************************ Functions Declarations *****************************/
/*****************************************************************************/

void AD7262_SwReset(void);
void AD7262_HwReset(void);
void AD7262_SetTestMode(void);
void AD7262_WriteEvalBoardRegister(unsigned char reg, unsigned int value);
unsigned int AD7262_ReadEvalBoardRegister(unsigned char reg);
void AD7262_SetGain(unsigned int gain);
void AD7262_SetPowerMode(unsigned int powermode);
void AD7262_InitPins(void);
void AD7262_Calibrate(void);
int  AD7262_StartAcquisition(int size, unsigned int destination);
int AD7262_ReadStatus (void);
int AD7262_ReadState (void);

#endif /*__ad7262_H__ */
