
#ifndef __AD7262_REGS_H__
#define __AD7262_REGS_H__

#include <io.h>

/* all registers are 32 bits wide .*/

// Control Register BASE_ADDR + 0x000
// bit 0 Start Acquisition
// bit 1 Software reset
// bit 2 Control_fixed_location
// bit 3 Write_EN for ADC
// bit 4 Test Mode

#define IOADDR_AD7262_CONTROL(base)           __IO_CALC_ADDRESS_NATIVE(base, 0)
#define IORD_AD7262_CONTROL(base)             IORD(base, 0)
#define IOWR_AD7262_CONTROL(base, data)       IOWR(base, 0, data)

// Counter Register BASE_ADDR + 0x001
// Counter to store the total number of sample acquisitions requested by software

#define IOADDR_AD7262_ACQ_COUNT(base)         __IO_CALC_ADDRESS_NATIVE(base, 1)
#define IORD_AD7262_ACQ_COUNT(base)           IORD(base, 1)
#define IOWR_AD7262_ACQ_COUNT(base, data)     IOWR(base, 1, data)

// BaseAddr Register BASE_ADDR + 0x002
// The base address where data will be written

#define IOADDR_AD7262_BASE(base)              __IO_CALC_ADDRESS_NATIVE(base, 2)
#define IORD_AD7262_BASE(base)                IORD(base, 2)
#define IOWR_AD7262_BASE(base, data)          IOWR(base, 2, data)

// Status Register BASE_ADDR + 0x003
// bit 0    Acquisition Complete
// bit 1    Buffer Overflow
// bit 2    Write Address Error
// bit 3:5  ADC address
// bit 6    Overrange Error
// bit 7    Data Valid
// bit 8    Low Power
// bit 9    Filter OK

#define IOADDR_AD7262_STATUS(base)          __IO_CALC_ADDRESS_NATIVE(base, 3)
#define IORD_AD7262_STATUS(base)            IORD(base, 3)
#define IOWR_AD7262_STATUS(base, data)      IOWR(base, 3, data)

// Data to be written to the ADC
// Write_Register BASE_ADDR + 0x004

#define IOADDR_AD7262_DUT_WR(base)          __IO_CALC_ADDRESS_NATIVE(base, 4)
#define IORD_AD7262_DUT_WR(base)            IORD(base, 4)
#define IOWR_AD7262_DUT_WR(base, data)      IOWR(base, 4, data)

// Data to be written to the ADC
// Write_Register BASE_ADDR + 0x005

#define IOADDR_AD7262_DUT_RD(base)          __IO_CALC_ADDRESS_NATIVE(base, 5)
#define IORD_AD7262_DUT_RD(base)            IORD(base, 5)
#define IOWR_AD7262_DUT_RD(base, data)      IOWR(base, 5, data)

// State Register, with the current states of the driver's FSMs
// State Register BASE_ADDR + 0x006

#define IOADDR_AD7262_DUT_STATE(base)       __IO_CALC_ADDRESS_NATIVE(base, 6)
#define IORD_AD7262_DUT_STATE(base)         IORD(base, 6)
#define IOWR_AD7262_DUT_STATE(base, data)   IOWR(base, 6, data)

#endif /* __AD7262_REGS_H__ */
