/**************************************************************************//**
*   @file   main.c
*   @brief  System validation program
*   @author Istvan Csomortani (istvan.csomortani@analog.com)
*
*******************************************************************************
* Copyright 2013(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1984
******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/

#include "unistd.h"
#include "system.h"
#include "unistd.h"
#include "Drivers/ced1z.h"
#include "ad7262_regs.h"
#include "ad7262.h"

/*****************************************************************************/
/************************ Variables Definitions ******************************/
/*****************************************************************************/

volatile unsigned int   *txData             = (unsigned int *) 0x4e0000;  // address of the start of the memory
volatile unsigned int   size                = MAX_MEMORY_LINES * MEMORY_LINE_SIZE;                                                     // used for the request of number of samples
volatile int            startAcquisition    = 0;                          // starts one acquisition cycle of 1MB
volatile short          channels            = 1;                          // By default read two channels

/*****************************************************************************/
/************************ Functions Definitions ******************************/
/*****************************************************************************/

int main()
{

    // pointer declaraction and intialisation
    volatile    int *startAcquisitionTCL    = (int *)0x4a0000;
    volatile    int *operationCompleteTCL   = (int *)0x4a000C;
    volatile    int *startAcqPointer        = (int *)0x4a0014;
    volatile    int *gainSetup              = (int *)0x4a0018;
    volatile    int *powerDownSetup         = (int *)0x4a001C;

    *startAcqPointer                        = (unsigned int)&startAcquisition;
    *startAcquisitionTCL                    = 0;
    *operationCompleteTCL                   = 0;
    *gainSetup                              = 0xFF;
    *powerDownSetup                         = 0xFF;

    // Initial pin setup
    AD7262_InitPins();

    // program the variable power pins
    configure_vio_fpga(VIO_FPGA_2_5V);
    configure_vara(VARA_5V);
    configure_vard(VARD_3_3V);
    // activate the programmable power pins, all voltages are ON, 12V selected
    init_power(N15_EN|N5VA_EN|P5VA_SD|VARA_SD|VARD_SD|P5VD_SD|P3VD_SD);
    // waiting for the EvalBoard to initialize
    usleep(500000);                //waiting for the EvalBoard to initialize

    // Reset the HDL core
    AD7262_SwReset();
    IOWR_ALTERA_AVALON_PIO_DATA(LED_BASE, 0x7); // power up process finished

    while(1)
    {
        while((*gainSetup == 0xFF) || (*powerDownSetup == 0xFF));
        // Set up the PGA and power-down modes
        AD7262_SetGain(*gainSetup);
        AD7262_SetPowerMode(*powerDownSetup);

        // Uncomment if you want to use the Test Mode
        // AD7262_SetTestMode();

        // The ADC is configured, waiting for the acquisition to start
        IOWR_ALTERA_AVALON_PIO_DATA (LED_BASE, 0x01);

        // Waiting for start acquisition
        while(startAcquisition == 0);

        // Signal the start of the data acquisition
        IOWR_ALTERA_AVALON_PIO_DATA (LED_BASE, 0x03);
        AD7262_StartAcquisition(size, (unsigned int)txData);

        //Wait for end of the acquisition
        while(!(AD7262_ReadStatus() & 0x00000001));

        IOWR_ALTERA_AVALON_PIO_DATA (LED_BASE, 0x05);
        //signal the start of data transfer to the PC
        *startAcquisitionTCL = 1;

        while (*operationCompleteTCL == 0);
        usleep(100);

        startAcquisition    = 0;
        *gainSetup          = 0xFF;
        *powerDownSetup     = 0xFF;

        IOWR_ALTERA_AVALON_PIO_DATA (LED_BASE, 0x01);
    }
return 0;
}
